@@ -2,19 +2,27 @@
 Functions and methods for performing comparison tests.
 
 """
-import numpy as np
+import copy
 import warnings
+
+import numpy as np
+import xarray as xr
+
 from act.utils.data_utils import convert_units
 from act.utils.datetime_utils import determine_time_delta
-import copy
-import xarray as xr
 
 
 class QCTests:
-    def compare_time_series_trends(self, var_name=None, comp_dataset=None,
-                                   comp_var_name=None, time_match_threshhold=60,
-                                   time_shift=60 * 60, time_step=None,
-                                   time_qc_threshold=60 * 15):
+    def compare_time_series_trends(
+        self,
+        var_name=None,
+        comp_dataset=None,
+        comp_var_name=None,
+        time_match_threshhold=60,
+        time_shift=60 * 60,
+        time_step=None,
+        time_qc_threshold=60 * 15,
+    ):
         """
         Method to perform a time series comparison test between two Xarray Datasets
         to detect a shift in time based on two similar variables. This test will
@@ -67,8 +75,9 @@ class QCTests:
         comp_da = copy.deepcopy(comp_dataset[comp_var_name])
 
         # Convert comp data units to match
-        comp_da.values = convert_units(comp_da.values, comp_da.attrs['units'],
-                                       self_da.attrs['units'])
+        comp_da.values = convert_units(
+            comp_da.values, comp_da.attrs['units'], self_da.attrs['units']
+        )
         comp_da.attrs['units'] = self_da.attrs['units']
 
         # Match comparison data to time of data
@@ -76,15 +85,17 @@ class QCTests:
             time_step = determine_time_delta(self._obj['time'].values)
         sum_diff = np.array([], dtype=float)
         time_diff = np.array([], dtype=np.int32)
-        for tm_shift in range(-1 * time_shift, time_shift + int(time_step),
-                              int(time_step)):
+        for tm_shift in range(-1 * time_shift, time_shift + int(time_step), int(time_step)):
             self_da_shifted = self_da.assign_coords(
-                time=self_da.time.values.astype('datetime64[s]') + tm_shift)
+                time=self_da.time.values.astype('datetime64[s]') + tm_shift
+            )
 
             data_matched, comp_data_matched = xr.align(self_da, comp_da)
             self_da_shifted = self_da_shifted.reindex(
-                time=comp_da.time.values, method='nearest',
-                tolerance=np.timedelta64(time_match_threshhold, 's'))
+                time=comp_da.time.values,
+                method='nearest',
+                tolerance=np.timedelta64(time_match_threshhold, 's'),
+            )
             diff = np.abs(self_da_shifted.values - comp_da.values)
             sum_diff = np.append(sum_diff, np.nansum(diff))
             time_diff = np.append(time_diff, tm_shift)
@@ -95,11 +106,13 @@ class QCTests:
         index = None
         if np.abs(time_diff) > time_qc_threshold:
             index = np.arange(0, self_da.size)
-        meaning = (f"Time shift detected with Minimum Difference test. Comparison of "
-                   f"{var_name} with {comp_var_name} off by {time_diff} seconds "
-                   f"exceeding absolute threshold of {time_qc_threshold} seconds.")
-        result = self._obj.qcfilter.add_test(var_name, index=index,
-                                             test_meaning=meaning,
-                                             test_assessment='Indeterminate')
+        meaning = (
+            f'Time shift detected with Minimum Difference test. Comparison of '
+            f'{var_name} with {comp_var_name} off by {time_diff} seconds '
+            f'exceeding absolute threshold of {time_qc_threshold} seconds.'
+        )
+        result = self._obj.qcfilter.add_test(
+            var_name, index=index, test_meaning=meaning, test_assessment='Indeterminate'
+        )
 
         return result
