@@ -4,29 +4,34 @@ Functions for radiosonde related calculations.
 """
 
 import warnings
+
 import numpy as np
 import pandas as pd
 import xarray as xr
+
 from act.utils.data_utils import convert_to_potential_temp
 
 try:
-    from pkg_resources import DistributionNotFound
     import metpy.calc as mpcalc
+    from pkg_resources import DistributionNotFound
+
     METPY_AVAILABLE = True
 except ImportError:
     METPY_AVAILABLE = False
 except (ModuleNotFoundError, DistributionNotFound):
-    warnings.warn("MetPy is installed but could not be imported. " +
-                  "Please check your MetPy installation. Some features " +
-                  "will be disabled.", ImportWarning)
+    warnings.warn(
+        'MetPy is installed but could not be imported. '
+        + 'Please check your MetPy installation. Some features '
+        + 'will be disabled.',
+        ImportWarning,
+    )
     METPY_AVAILABLE = False
 
 if METPY_AVAILABLE:
     from metpy.units import units
 
 
-def calculate_precipitable_water(ds, temp_name='tdry', rh_name='rh',
-                                 pres_name='pres'):
+def calculate_precipitable_water(ds, temp_name='tdry', rh_name='rh', pres_name='pres'):
     """
 
     Function to calculate precipitable water vapor from ARM sondewnpn b1 data.
@@ -61,17 +66,15 @@ def calculate_precipitable_water(ds, temp_name='tdry', rh_name='rh',
     for t in temperature:
         # Over liquid water, above freezing
         if t >= 0:
-            sat_vap_pres.append(0.61121 * np.exp((18.678 - (t / 234.5)) *
-                                (t / (257.14 + t))))
+            sat_vap_pres.append(0.61121 * np.exp((18.678 - (t / 234.5)) * (t / (257.14 + t))))
         # Over ice, below freezing
         else:
-            sat_vap_pres.append(0.61115 * np.exp((23.036 - (t / 333.7)) *
-                                (t / (279.82 + t))))
+            sat_vap_pres.append(0.61115 * np.exp((23.036 - (t / 333.7)) * (t / (279.82 + t))))
 
     # convert rh from % to decimal
     rel_hum = []
     for r in np.nditer(rh):
-        rel_hum.append(r / 100.)
+        rel_hum.append(r / 100.0)
 
     # get vapor pressure from rh and saturation vapor pressure
     vap_pres = []
@@ -100,18 +103,20 @@ def calculate_precipitable_water(ds, temp_name='tdry', rh_name='rh',
 
     pwv = 0.0
     for i in range(1, len(pressure) - 1):
-        pwv = pwv + 0.5 * (spec_hum[i] + spec_hum[i - 1]) * (pressure[i - 1] -
-                                                             pressure[i])
+        pwv = pwv + 0.5 * (spec_hum[i] + spec_hum[i - 1]) * (pressure[i - 1] - pressure[i])
 
     pwv = pwv / 0.098
     return pwv
 
 
-def calculate_stability_indicies(ds, temp_name="temperature",
-                                 td_name="dewpoint_temperature",
-                                 p_name="pressure",
-                                 rh_name='relative_humidity',
-                                 moving_ave_window=0):
+def calculate_stability_indicies(
+    ds,
+    temp_name='temperature',
+    td_name='dewpoint_temperature',
+    p_name='pressure',
+    rh_name='relative_humidity',
+    moving_ave_window=0,
+):
     """
     Function for calculating stability indices from sounding data.
 
@@ -140,31 +145,29 @@ def calculate_stability_indicies(ds, temp_name="temperature",
 
     """
     if not METPY_AVAILABLE:
-        raise ImportError("MetPy need to be installed on your system to " +
-                          "calculate stability indices")
+        raise ImportError(
+            'MetPy need to be installed on your system to ' + 'calculate stability indices'
+        )
 
     t = ds[temp_name]
     td = ds[td_name]
     p = ds[p_name]
     rh = ds[rh_name]
 
-    if not hasattr(t, "units"):
-        raise AttributeError("Temperature field must have units" +
-                             " for ACT to discern!")
+    if not hasattr(t, 'units'):
+        raise AttributeError('Temperature field must have units' + ' for ACT to discern!')
 
-    if not hasattr(td, "units"):
-        raise AttributeError("Dewpoint field must have units" +
-                             " for ACT to discern!")
+    if not hasattr(td, 'units'):
+        raise AttributeError('Dewpoint field must have units' + ' for ACT to discern!')
 
-    if not hasattr(p, "units"):
-        raise AttributeError("Pressure field must have units" +
-                             " for ACT to discern!")
-    if t.units == "C":
+    if not hasattr(p, 'units'):
+        raise AttributeError('Pressure field must have units' + ' for ACT to discern!')
+    if t.units == 'C':
         t_units = units.degC
     else:
         t_units = getattr(units, t.units)
 
-    if td.units == "C":
+    if td.units == 'C':
         td_units = units.degC
     else:
         td_units = getattr(units, td.units)
@@ -184,14 +187,10 @@ def calculate_stability_indicies(ds, temp_name="temperature",
     rh_sorted = rh_sorted[ind_sort[-1:0:-1]]
 
     if moving_ave_window > 0:
-        t_sorted = np.convolve(
-            t_sorted, np.ones((moving_ave_window,)) / moving_ave_window)
-        td_sorted = np.convolve(
-            td_sorted, np.ones((moving_ave_window,)) / moving_ave_window)
-        p_sorted = np.convolve(
-            p_sorted, np.ones((moving_ave_window,)) / moving_ave_window)
-        rh_sorted = np.convolve(
-            rh_sorted, np.ones((moving_ave_window,)) / moving_ave_window)
+        t_sorted = np.convolve(t_sorted, np.ones((moving_ave_window,)) / moving_ave_window)
+        td_sorted = np.convolve(td_sorted, np.ones((moving_ave_window,)) / moving_ave_window)
+        p_sorted = np.convolve(p_sorted, np.ones((moving_ave_window,)) / moving_ave_window)
+        rh_sorted = np.convolve(rh_sorted, np.ones((moving_ave_window,)) / moving_ave_window)
 
     t_sorted = t_sorted * t_units
     td_sorted = td_sorted * td_units
@@ -199,68 +198,73 @@ def calculate_stability_indicies(ds, temp_name="temperature",
     rh_sorted = rh_sorted * rh_units
 
     # Calculate mixing ratio
-    mr = mpcalc.mixing_ratio_from_relative_humidity(
-        p_sorted, t_sorted, rh_sorted)
+    mr = mpcalc.mixing_ratio_from_relative_humidity(p_sorted, t_sorted, rh_sorted)
 
     # Discussion of issue #361 use virtual temperature.
     vt = mpcalc.virtual_temperature(t_sorted, mr)
 
-    t_profile = mpcalc.parcel_profile(
-        p_sorted, t_sorted[0], td_sorted[0])
+    t_profile = mpcalc.parcel_profile(p_sorted, t_sorted[0], td_sorted[0])
 
     # Calculate parcel trajectory
-    ds["parcel_temperature"] = t_profile.magnitude
-    ds["parcel_temperature"].attrs['units'] = t_profile.units
+    ds['parcel_temperature'] = t_profile.magnitude
+    ds['parcel_temperature'].attrs['units'] = t_profile.units
 
     # Calculate CAPE, CIN, LCL
-    sbcape, sbcin = mpcalc.surface_based_cape_cin(
-        p_sorted, vt, td_sorted)
+    sbcape, sbcin = mpcalc.surface_based_cape_cin(p_sorted, vt, td_sorted)
 
-    lcl = mpcalc.lcl(
-        p_sorted[0], t_sorted[0], td_sorted[0])
+    lcl = mpcalc.lcl(p_sorted[0], t_sorted[0], td_sorted[0])
     try:
-        lfc = mpcalc.lfc(
-            p_sorted[0], t_sorted[0], td_sorted[0])
+        lfc = mpcalc.lfc(p_sorted[0], t_sorted[0], td_sorted[0])
     except IndexError:
         lfc = np.nan * p_sorted.units
 
-    mucape, mucin = mpcalc.most_unstable_cape_cin(
-        p_sorted, vt, td_sorted)
+    mucape, mucin = mpcalc.most_unstable_cape_cin(p_sorted, vt, td_sorted)
 
     where_500 = np.argmin(np.abs(p_sorted - 500 * units.hPa))
     li = t_sorted[where_500] - t_profile[where_500]
 
-    ds["surface_based_cape"] = sbcape.magnitude
-    ds["surface_based_cape"].attrs['units'] = "J/kg"
-    ds["surface_based_cape"].attrs['long_name'] = "Surface-based CAPE"
-    ds["surface_based_cin"] = sbcin.magnitude
-    ds["surface_based_cin"].attrs['units'] = "J/kg"
-    ds["surface_based_cin"].attrs['long_name'] = "Surface-based CIN"
-    ds["most_unstable_cape"] = mucape.magnitude
-    ds["most_unstable_cape"].attrs['units'] = "J/kg"
-    ds["most_unstable_cape"].attrs['long_name'] = "Most unstable CAPE"
-    ds["most_unstable_cin"] = mucin.magnitude
-    ds["most_unstable_cin"].attrs['units'] = "J/kg"
-    ds["most_unstable_cin"].attrs['long_name'] = "Most unstable CIN"
-    ds["lifted_index"] = li.magnitude
-    ds["lifted_index"].attrs['units'] = t_profile.units
-    ds["lifted_index"].attrs['long_name'] = "Lifted index"
-    ds["level_of_free_convection"] = lfc.magnitude
-    ds["level_of_free_convection"].attrs['units'] = lfc.units
-    ds["level_of_free_convection"].attrs['long_name'] = "Level of free convection"
-    ds["lifted_condensation_level_temperature"] = lcl[1].magnitude
-    ds["lifted_condensation_level_temperature"].attrs['units'] = lcl[1].units
-    ds["lifted_condensation_level_temperature"].attrs[
-        'long_name'] = "Lifted condensation level temperature"
-    ds["lifted_condensation_level_pressure"] = lcl[0].magnitude
-    ds["lifted_condensation_level_pressure"].attrs['units'] = lcl[0].units
-    ds["lifted_condensation_level_pressure"].attrs[
-        'long_name'] = "Lifted condensation level pressure"
+    ds['surface_based_cape'] = sbcape.magnitude
+    ds['surface_based_cape'].attrs['units'] = 'J/kg'
+    ds['surface_based_cape'].attrs['long_name'] = 'Surface-based CAPE'
+    ds['surface_based_cin'] = sbcin.magnitude
+    ds['surface_based_cin'].attrs['units'] = 'J/kg'
+    ds['surface_based_cin'].attrs['long_name'] = 'Surface-based CIN'
+    ds['most_unstable_cape'] = mucape.magnitude
+    ds['most_unstable_cape'].attrs['units'] = 'J/kg'
+    ds['most_unstable_cape'].attrs['long_name'] = 'Most unstable CAPE'
+    ds['most_unstable_cin'] = mucin.magnitude
+    ds['most_unstable_cin'].attrs['units'] = 'J/kg'
+    ds['most_unstable_cin'].attrs['long_name'] = 'Most unstable CIN'
+    ds['lifted_index'] = li.magnitude
+    ds['lifted_index'].attrs['units'] = t_profile.units
+    ds['lifted_index'].attrs['long_name'] = 'Lifted index'
+    ds['level_of_free_convection'] = lfc.magnitude
+    ds['level_of_free_convection'].attrs['units'] = lfc.units
+    ds['level_of_free_convection'].attrs['long_name'] = 'Level of free convection'
+    ds['lifted_condensation_level_temperature'] = lcl[1].magnitude
+    ds['lifted_condensation_level_temperature'].attrs['units'] = lcl[1].units
+    ds['lifted_condensation_level_temperature'].attrs[
+        'long_name'
+    ] = 'Lifted condensation level temperature'
+    ds['lifted_condensation_level_pressure'] = lcl[0].magnitude
+    ds['lifted_condensation_level_pressure'].attrs['units'] = lcl[0].units
+    ds['lifted_condensation_level_pressure'].attrs[
+        'long_name'
+    ] = 'Lifted condensation level pressure'
     return ds
 
 
-def calculate_pbl_liu_liang(ds, temperature='tdry', pressure='pres', windspeed='wspd', height='alt',
-                            smooth_height=3, land_parameter=True, llj_max_alt=1500., llj_max_wspd=2.):
+def calculate_pbl_liu_liang(
+    ds,
+    temperature='tdry',
+    pressure='pres',
+    windspeed='wspd',
+    height='alt',
+    smooth_height=3,
+    land_parameter=True,
+    llj_max_alt=1500.0,
+    llj_max_wspd=2.0,
+):
     """
     Function for calculating the PBL height from a radiosonde profile
     using the Liu-Liang 2010 technique.  There are some slight descrepencies
@@ -316,12 +320,14 @@ def calculate_pbl_liu_liang(ds, temperature='tdry', pressure='pres', windspeed='
 
     base = 5  # 5 mb base
     starting_pres = base * np.ceil(float(obj[pressure].values[2]) / base)
-    p_grid = np.flip(np.arange(100., starting_pres + base, base))
+    p_grid = np.flip(np.arange(100.0, starting_pres + base, base))
 
     try:
         obj = obj.sel(pres=p_grid, method='nearest')
     except Exception:
-        ds[pressure] = ds[pressure].rolling(time=smooth_height + 4, min_periods=2, center=True).mean()
+        ds[pressure] = (
+            ds[pressure].rolling(time=smooth_height + 4, min_periods=2, center=True).mean()
+        )
         obj = ds.swap_dims(dims_dict={'time': pressure})
         for var in obj:
             obj[var].attrs = ds[var].attrs
@@ -332,7 +338,9 @@ def calculate_pbl_liu_liang(ds, temperature='tdry', pressure='pres', windspeed='
 
     # Get Data Variables
     if smooth_height > 0:
-        alt = pd.Series(obj[height].values).rolling(window=smooth_height, min_periods=0).mean().values
+        alt = (
+            pd.Series(obj[height].values).rolling(window=smooth_height, min_periods=0).mean().values
+        )
     else:
         alt = obj[height].values
     if np.isnan(alt[0]):
@@ -346,37 +354,40 @@ def calculate_pbl_liu_liang(ds, temperature='tdry', pressure='pres', windspeed='
 
     # Perform Pre-processing checks
     if len(temp) == 0:
-        raise ValueError("No data in profile")
+        raise ValueError('No data in profile')
 
-    if np.nanmax(alt) < 1000.:
-        raise ValueError("Max altitude < 1000m")
+    if np.nanmax(alt) < 1000.0:
+        raise ValueError('Max altitude < 1000m')
 
-    if np.nanmax(pres) <= 200.:
-        raise ValueError("Max pressure <= 200 hPa")
+    if np.nanmax(pres) <= 200.0:
+        raise ValueError('Max pressure <= 200 hPa')
 
     # Check temperature delta
     t1 = time_0[0]
     t2 = t1 + np.timedelta64(10, 's')
     idx = np.where((time_0 >= t1) & (time_0 <= t2))[0]
     t_delta = abs(temp_0[idx[-1]] - temp_0[idx[0]])
-    if t_delta > 30.:
+    if t_delta > 30.0:
         raise ValueError('Temperature changes by >30º in first 10 seconds')
 
     # Check min/max
-    if np.nanmax(temp) > 50. or np.nanmin(temp) < -90:
+    if np.nanmax(temp) > 50.0 or np.nanmin(temp) < -90:
         raise ValueError('Temperature outside acceptable range (-90, 50)')
 
     if np.isnan(pres[0]) or np.isnan(pres[1]):
         raise ValueError('First two pressure values bad')
 
     # Calculate potential temperature and subsequent gradients
-    theta = convert_to_potential_temp(obj=obj, temp_var_name=temperature, press_var_name='pres') + 273.15
+    theta = (
+        convert_to_potential_temp(obj=obj, temp_var_name=temperature, press_var_name='pres')
+        + 273.15
+    )
     atts = {'units': 'K', 'long_name': 'Potential temperature'}
     da = xr.DataArray(theta, coords=obj['tdry'].coords, dims=obj[temperature].dims, attrs=atts)
     obj['potential_temperature'] = da
 
     theta_diff = theta[4] - theta[1]
-    theta_gradient = np.diff(theta) / np.diff(alt / 1000.)
+    theta_gradient = np.diff(theta) / np.diff(alt / 1000.0)
 
     # Set up threshold values
     if land_parameter:
@@ -410,21 +421,29 @@ def calculate_pbl_liu_liang(ds, temperature='tdry', pressure='pres', windspeed='
 
         # Scan upward to find lowest level that meets condition
         idx = np.where(theta_gradient_0 >= inst_thresh)[0]
-        theta_gradient[0:idx[0]] = np.nan
+        theta_gradient[0 : idx[0]] = np.nan
 
         # Scan upward from previous level to search for overlying inversion layer
         idx = np.where(theta_gradient >= overshoot_thresh)[0]
         pbl = alt[idx[0]]
     else:
-        idx = np.array([i for i, t in enumerate(theta_gradient[1:-1]) if theta_gradient[i] <
-                        theta_gradient[i - 1] and theta_gradient[i] < theta_gradient[i + 1]])
+        idx = np.array(
+            [
+                i
+                for i, t in enumerate(theta_gradient[1:-1])
+                if theta_gradient[i] < theta_gradient[i - 1]
+                and theta_gradient[i] < theta_gradient[i + 1]
+            ]
+        )
 
         for i in idx:
-            cond1 = (theta_gradient[i] - theta_gradient[i - 1]) < -40.
-            cond2 = (theta_gradient[i + 1] < overshoot_thresh) or (theta_gradient[i + 2] < overshoot_thresh)
+            cond1 = (theta_gradient[i] - theta_gradient[i - 1]) < -40.0
+            cond2 = (theta_gradient[i + 1] < overshoot_thresh) or (
+                theta_gradient[i + 2] < overshoot_thresh
+            )
             if cond1 or cond2:
                 # This gets the ARM answer
-                pbl_stable = (alt[i + 1] + alt[i]) / 2.
+                pbl_stable = (alt[i + 1] + alt[i]) / 2.0
                 # pbl_stable = alt[i]
                 break
 
@@ -435,24 +454,27 @@ def calculate_pbl_liu_liang(ds, temperature='tdry', pressure='pres', windspeed='
         # the lowest 1500m of the atmosphere. Keywords to adjust are provided
         idh = np.where(alt <= llj_max_alt)[0]
         max_wspd_ind = [i for i, w in enumerate(wspd[:-1]) if wspd[i] > wspd[i + 1]][0]
-        diff = wspd[max_wspd_ind] - wspd[max_wspd_ind:idh[-1]]
+        diff = wspd[max_wspd_ind] - wspd[max_wspd_ind : idh[-1]]
         idx = np.where(diff > llj_max_wspd)[0]
         if len(idx) > 0:
             wspd_to_surf = np.diff(np.flip(wspd[0:max_wspd_ind]))
-            wspd_monotonic = np.all(wspd_to_surf <= 0.)
+            wspd_monotonic = np.all(wspd_to_surf <= 0.0)
             if wspd_monotonic:
                 pbl_shear = alt[max_wspd_ind]
 
         if ~np.all(np.isnan([pbl_stable, pbl_shear])):
             pbl = np.nanmin([pbl_stable, pbl_shear])
         else:
-            pbl = -9999.
+            pbl = -9999.0
 
     atts = {'units': 'm', 'long_name': 'Planteary Boundary Layer Height Liu-Liang'}
     da = xr.DataArray(pbl, attrs=atts)
     ds['pblht_liu_liang'] = da
 
-    atts = {'units': '', 'long_name': 'Planteary Boundary Layer Regime Classification Liu-Liang'}
+    atts = {
+        'units': '',
+        'long_name': 'Planteary Boundary Layer Regime Classification Liu-Liang',
+    }
     da = xr.DataArray(regime, attrs=atts)
     ds['pblht_regime_liu_liang'] = da
 
