@@ -4,11 +4,12 @@ Module that containing utilities involving datetimes.
 """
 
 import datetime as dt
-import pandas as pd
-import numpy as np
-from scipy import stats
 import warnings
 
+import numpy as np
+import pandas as pd
+from scipy import stats
+
 
 def dates_between(sdate, edate):
     """
@@ -29,10 +30,10 @@ def dates_between(sdate, edate):
         The array containing the dates between *sdate* and *edate*.
 
     """
-    days = dt.datetime.strptime(edate, '%Y%m%d') - \
-        dt.datetime.strptime(sdate, '%Y%m%d')
-    all_dates = [dt.datetime.strptime(sdate, '%Y%m%d') + dt.timedelta(days=d)
-                 for d in range(days.days + 1)]
+    days = dt.datetime.strptime(edate, '%Y%m%d') - dt.datetime.strptime(sdate, '%Y%m%d')
+    all_dates = [
+        dt.datetime.strptime(sdate, '%Y%m%d') + dt.timedelta(days=d) for d in range(days.days + 1)
+    ]
     return all_dates
 
 
@@ -99,16 +100,17 @@ def reduce_time_ranges(time, time_delta=60, broken_barh=False):
 
     # Create a list of tuples containg time ranges or start time with duration
     if broken_barh:
-        return [(time[dd[ii] + 1], time[dd[ii + 1]] - time[dd[ii] + 1])
-                for ii in range(len(dd) - 1)]
+        return [
+            (time[dd[ii] + 1], time[dd[ii + 1]] - time[dd[ii] + 1]) for ii in range(len(dd) - 1)
+        ]
     else:
         return [(time[dd[ii] + 1], time[dd[ii + 1]]) for ii in range(len(dd) - 1)]
 
 
 def determine_time_delta(time, default=60):
     """
-    Returns the most likely time step in seconds by analyzing the difference in
-    time steps.
+    Returns the most likely time step in seconds by analyzing the difference
+    in time steps.
 
     Parameters
     ----------
@@ -125,7 +127,7 @@ def determine_time_delta(time, default=60):
 
     """
     with warnings.catch_warnings():
-        warnings.filterwarnings("ignore", category=RuntimeWarning)
+        warnings.filterwarnings('ignore', category=RuntimeWarning)
         if time.size > 1:
             mode = stats.mode(np.diff(time))
             time_delta = mode.mode[0]
@@ -138,23 +140,70 @@ def determine_time_delta(time, default=60):
 
 def datetime64_to_datetime(time):
     """
-    Given a numpy datetime64 array time series, return datetime (y, m, d, h, m, s)
+    Given a numpy datetime64 array time series, return datetime
+    (y, m, d, h, m, s)
 
     Parameters
     ----------
-    time: numpy datetime64 array, list of numpy datetime64 values or scalar numpy datetime64
-        The numpy array of date time values.
+    time : numpy datetime64 array, list of numpy datetime64 values or
+        scalar numpy datetime64. The numpy array of date time values.
 
     Returns
     -------
-    datetime: list
+    datetime : list
         Returns a list of datetimes (y, m, d, h, m, s) from a time series.
+        YYYY-MM-DD, DD.MM.YYYY, DD/MM/YYYY or YYYYMMDD.
 
     """
     if isinstance(time, (tuple, list)):
         time = np.array(time)
     if len(time.shape) == 0:
         time = np.array([time])
-    datetime_array = [dt.datetime.fromtimestamp(tm.astype('datetime64[ms]').astype('float') / 1000.,
-                                                tz=dt.timezone.utc).replace(tzinfo=None) for tm in time]
+    datetime_array = [
+        dt.datetime.fromtimestamp(
+            tm.astype('datetime64[ms]').astype('float') / 1000.0, tz=dt.timezone.utc
+        ).replace(tzinfo=None)
+        for tm in time
+    ]
     return datetime_array
+
+
+def date_parser(date_string, output_format='%Y%m%d',
+                return_datetime=False):
+    """ Converts one datetime string to another or to
+    a datetime object.
+
+    Parameters
+    ----------
+    date_string : str
+        datetime string to be parsed. Accepted formats are
+        YYYY-MM-DD, DD.MM.YYYY, DD/MM/YYYY or YYYYMMDD.
+    output_format : str
+        Format for datetime.strftime to output datetime string.
+    return_datetime : bool
+        If true, returns str as a datetime object.
+        Default is False.
+
+    returns
+    -------
+    datetime_str : str
+        A valid datetime string.
+    datetime_obj : datetime.datetime
+        A datetime object.
+
+    """
+    date_fmts = ['%Y-%m-%d', '%d.%m.%Y',
+                 '%d/%m/%Y', '%Y%m%d', '%Y/%m/%d']
+    for fmt in date_fmts:
+        try:
+            datetime_obj = dt.datetime.strptime(date_string, fmt)
+            if return_datetime:
+                return datetime_obj
+            else:
+                return datetime_obj.strftime(output_format)
+        except ValueError:
+            pass
+    fmt_strings = ', '.join(date_fmts)
+    raise ValueError(
+        'Invalid Date format, please use one of these formats '
+        + fmt_strings)
